
.. _zttt_main:

ZTicTacToe
============

Tic Tac Toe is a famous game in which two players take turns placing
a mark on a 3x3 grid. The first player to get three in a row wins.

The module is a standalone implementation of the game TicTacToe
providing functionality to keep track of the game's state and to
make moves.


.. _zttt_features:

Features
---------
- Standalone implementation of the game Tic Tac Toe.
- Provides a way to customise **move triggers** and access state variables.
- Comes with an engine with near perfect moves.
- Written in Python from scratch and does not require any external libraries.
- Can be integrated into a larger project, with very little effort.
- Throws custom-built errors making it easy to debug and handle errors.



.. _zttt_links:

Links
------
- `PyPI <https://pypi.python.org/pypi/zttt>`_
- `GitHub <https://github.com/Sigma1084/ZTicTacToe/tree/v1>`_
- `Documentation <https://ztictactoe.readthedocs.io/en/v1/>`_
- `Examples <https://github.com/Sigma1084/ZTicTacToe/tree/v1/examples>`_

.. _zttt_install:

Installation
-------------
.. code-block:: bash

    pip install zttt
